@@ -49,9 +49,12 @@ func TestDumpSystem(t *testing.T) {
 
 		dumpSystem := NewDumpSystem()
 		persistentState := NewMockPersistentState()
-		assert.NoError(t, s.applyAll(dumpSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
-			Filter: NewEntryTypeFilter(EntryTypesAll, EntryTypesNone),
-		}))
+		assert.NoError(
+			t,
+			s.applyAll(dumpSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
+				Filter: NewEntryTypeFilter(EntryTypesAll, EntryTypesNone),
+			}),
+		)
 		expectedData := map[string]any{
 			".dir": &dirData{
 				Type: dataTypeDir,
